==> nnn_3.5.orig.tar.gz: nnn-3.5/.github/ISSUE_TEMPLATE/bug_report.md <==
---
name: Bug report
about: Create a report to help us improve
title: ''
labels: bug
assignees: ''
---

`nnn` comes with excellent documentation (including a Troubleshooting section). If you have a _How to do x_ question, it may have already been answered. Wiki: https://github.com/jarun/nnn/wiki

If it looks like a local environment issue, please try to debug yourself. Debugging local setup issues is not our top priority.

If you are looking for a new feature or program option, ensure you have the correct version with the feature installed. Refer to the release notes to confirm.

Before opening an issue, please try to reproduce on latest master. The bug you noticed might have already been fixed.

Useful links:

- compile `nnn` from source - https://github.com/jarun/nnn/wiki/Usage#from-source
- debugging `nnn` - https://github.com/jarun/nnn/wiki/Developer-guides#debugging-nnn

If the issue can be reproduced on master, log it.

Please provide the environment details. **If that's missing, the issue will be closed without any cited reason.**

If we need more information and there is no communication from the bug reporter within 7 days from the date of request, we will close the issue. If you have relevant information, resume discussion any time.

--- PLEASE DELETE THIS LINE AND EVERYTHING ABOVE ---

#### Environment details (Put `x` in the checkbox along with the information)

[ ] Operating System:
[ ] Desktop Environment:
[ ] Terminal Emulator:
[ ] Shell:
[ ] Custom desktop opener (if applicable):
[ ] Program options used:
[ ] Configuration options set:
[ ] Issue exists on `nnn` master

#### Exact steps to reproduce the issue

==> nnn_4.3.orig.tar.gz: nnn-4.3/.github/ISSUE_TEMPLATE/bug_report.md <==
---
name: Bug report
about: Create a report to help us improve
title: ''
labels: bug
assignees: ''
---

`nnn` comes with excellent documentation (including a Troubleshooting section). If you have a _How to do x_ question, it may have already been answered. Wiki: https://github.com/jarun/nnn/wiki

If it looks like a local environment issue, please try to debug yourself. Debugging local setup issues is not our top priority.

If you are looking for a new feature or program option, ensure you have the correct version with the feature installed. Refer to the release notes to confirm.

Before opening an issue, please try to reproduce on latest master. The bug you noticed might have already been fixed.

Useful links:

- compile `nnn` from source - https://github.com/jarun/nnn/wiki/Usage#from-source
- debugging `nnn` - https://github.com/jarun/nnn/wiki/Developer-guides#debugging-nnn

If the issue can be reproduced on master, log it.

Please provide the environment details. **If that's missing, the issue will be closed without any cited reason.**

If we need more information and there is no communication from the bug reporter within 7 days from the date of request, we will close the issue. If you have relevant information, resume discussion any time.

--- PLEASE DELETE THIS LINE AND EVERYTHING ABOVE ---

#### Environment details (Put `x` in the checkbox along with the information)

- [ ] Operating System:
- [ ] Desktop Environment:
- [ ] Terminal Emulator:
- [ ] Shell:
- [ ] Custom desktop opener (if applicable):
- [ ] Program options used:
- [ ] Configuration options set:
- [ ] Issue exists on `nnn` master

#### Exact steps to reproduce the issue
